@@ -3,8 +3,8 @@ require 'world'
 class AdventureMUC
   def initialize(jid, secret, addr, port=5347)
     @worlds = {}
-    
-    @component = Jabber::Component::new(jid)
+
+    @component = Jabber::Component.new(jid)
     @component.connect(addr, port)
     @component.auth(secret)
     @component.on_exception { |e,|
@@ -37,7 +37,7 @@ class AdventureMUC
   end
 
   def send(worldnode, worldresource, stanza)
-    stanza.from = Jabber::JID::new(worldnode, @component.jid.domain, worldresource)
+    stanza.from = Jabber::JID.new(worldnode, @component.jid.domain, worldresource)
     @component.send(stanza)
   end
 
@@ -54,16 +54,16 @@ class AdventureMUC
       false
     end
   end
-  
+
   def handle_disco_info(iq)
     if iq.type != :get
-      answer = Jabber::XMLStanza.answer(iq)
+      answer = iq.answer
       answer.type = :error
-      answer.add(Jabber::Error.new('bad-request'))
+      answer.add(Jabber::ErrorResponse.new('bad-request'))
       @component.send(answer) if iq.type != :error
       return
     end
-    answer = Jabber::XMLStanza.answer(iq)
+    answer = iq.answer
     answer.type = :result
     if iq.to.node == nil
       answer.query.add(Jabber::Discovery::Identity.new('conference', 'Adventure component', 'text'))
@@ -73,7 +73,7 @@ class AdventureMUC
       world = @worlds[iq.to.node]
       if world.nil?
         answer.type = :error
-        answer.query.add(Jabber::Error.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
+        answer.query.add(Jabber::ErrorResponse.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
       else
         answer.query.add(Jabber::Discovery::Identity.new('conference', world.iname, 'text'))
         answer.query.add(Jabber::Discovery::Feature.new(Jabber::Discovery::IqQueryDiscoInfo.new.namespace))
@@ -84,19 +84,19 @@ class AdventureMUC
     end
     @component.send(answer)
   end
-  
+
   def handle_disco_items(iq)
     if iq.type != :get
-      answer = Jabber::XMLStanza.answer(iq)
-      answer.add(Jabber::Error.new('bad-request'))
+      answer = iq.answer
+      answer.add(Jabber::ErrorResponse.new('bad-request'))
       @component.send(answer)
       return
     end
-    answer = Jabber::XMLStanza.answer(iq)
+    answer = iq.answer
     answer.type = :result
     if iq.to.node == nil
       @worlds.each { |node,world|
-        answer.query.add(Jabber::Discovery::Item.new(Jabber::JID::new(node, @component.jid.domain), world.iname))
+        answer.query.add(Jabber::Discovery::Item.new(Jabber::JID.new(node, @component.jid.domain), world.iname))
       }
     end
     @component.send(answer)
@@ -104,12 +104,12 @@ class AdventureMUC
 
   def handle_presence(pres)
     puts "presence: from #{pres.from} type #{pres.type} to #{pres.to}"
-    
+
     world = @worlds[pres.to.node]
     if world.nil?
-      answer = Jabber::XMLStanza.answer(pres)
+      answer = pres.answer
       answer.type = :error
-      answer.add(Jabber::Error.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
+      answer.add(Jabber::ErrorResponse.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
       @component.send(answer)
     else
       world.handle_presence(pres)
@@ -123,9 +123,9 @@ class AdventureMUC
 
     world = @worlds[msg.to.node]
     if world.nil?
-      answer = Jabber::XMLStanza.answer(msg)
+      answer = msg.answer
       answer.type = :error
-      answer.add(Jabber::Error.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
+      answer.add(Jabber::ErrorResponse.new('item-not-found', 'The world you are trying to reach is currently unavailable.'))
       @component.send(answer)
     else
       world.handle_message(msg)
