@@ -7,6 +7,12 @@ module Jabber
     ##
     # SOCKS5 Bytestreams implementation of the target site
     class SOCKS5BytestreamsTarget < SOCKS5Bytestreams
+      ##
+      # See SOCKS5Bytestreams#initialize
+      def initialize(stream, session_id, initiator_jid, target_jid)
+        @connect_timeout = 60
+        super
+      end
       ##
       # Wait until the stream has been established
       #
@@ -39,13 +45,13 @@ module Jabber
                 reply.query.add(StreamHostUsed.new(@streamhost_used.jid))
               else
                 reply.type = :error
-                reply.add(Error.new('item-not-found'))
+                reply.add(ErrorResponse.new('item-not-found'))
               end
               @stream.send(reply)
             rescue Exception => e
               error = e
             end
-              
+
             connect_sem.run
             true
           else
@@ -53,11 +59,15 @@ module Jabber
           end
         }
 
-        connect_sem.wait
+        begin
+          Timeout::timeout(@connect_timeout) { connect_sem.wait }
+        rescue Timeout::Error
+          @stream.delete_iq_callback(self)
+        end
+
         raise error if error
         (@socks != nil)
       end
     end
   end
 end
-
