@@ -23,12 +23,12 @@ module Jabber
 
     # Create a new Component
     # jid:: [JID]
-    def initialize(jid, server_address=nil, server_port=5347, threaded = true)
-      super(threaded)
+    def initialize(jid, server_address=nil, server_port=5347)
+      super()
       @jid = (jid.kind_of?(JID) ? jid : JID.new(jid.to_s))
 
       if server_address
-        $stderr.puts "Passing server and port to Jabber::Component::new is " +
+        $stderr.puts "Passing server and port to Jabber::Component.new is " +
                      "obsolete and will vanish in some later XMPP4R release. " +
                      "Please use these arguments when calling " +
                      "Jabber::Client#connect"
@@ -36,7 +36,7 @@ module Jabber
         @server_port = server_port
       end
     end
-    
+
     # Connect to the server
     # (chaining-friendly)
     # server:: [String] Hostname
@@ -80,10 +80,10 @@ module Jabber
     ##
     # Send auth with given secret and wait for result
     #
-    # Throws AuthenticationFailure
-    # secret:: [String] the shared secret 
+    # Throws ComponentAuthenticationFailure
+    # secret:: [String] the shared secret
     def auth(secret)
-      hash = Digest::SHA1::new(@streamid.to_s + secret).to_s
+      hash = Digest::SHA1::hexdigest(@streamid.to_s + secret)
       authenticated = false
       send("<handshake>#{hash}</handshake>") { |r|
         if r.prefix == 'stream' and r.name == 'error'
@@ -96,8 +96,8 @@ module Jabber
         end
       }
       unless authenticated
-        raise AuthenticationFailure.new, "Component authentication failed"
+        raise ComponentAuthenticationFailure.new, "Component authentication failed"
       end
     end
-  end  
+  end
 end
