@@ -28,10 +28,11 @@ module Jabber
         nil
       end
 
-      def fields
+      def fields(including_hidden=false)
         fields = []
         each_element do |xe|
-          if xe.kind_of?(XDataField) and xe.type != :hidden and xe.type != :fixed
+          if xe.kind_of?(XDataField) and (including_hidden or
+                                          (xe.type != :hidden and xe.type != :fixed))
             fields << xe
           end
         end
@@ -90,9 +91,9 @@ module Jabber
         each_element('instructions') do |xe|
           fields << xe
         end
-        fields        
+        fields
       end
-  
+
       ##
       # Add Data Form instructions
       # i:: [String]
@@ -251,6 +252,18 @@ module Jabber
         }
       end
 
+      ##
+      # Get the first value
+      def value
+        values.first
+      end
+
+      ##
+      # Remove all and set one value
+      def value=(val)
+        self.values = [val]
+      end
+
       ##
       # Get the options (in a Data Form with type='form')
       def options
@@ -282,4 +295,3 @@ module Jabber
     end
   end
 end
-
